summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildview.cpp')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildview.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp b/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
index 94670ce8..7189b571 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildview.cpp
@@ -115,7 +115,7 @@ TQRect KMdiChildView::internalGeometry() const
{ // is attached
// get the client area coordinates inside the MDI child frame
TQRect posInFrame = tqgeometry();
// map these values to the tqparent of the MDI child frame
// (this usually is the MDI child area) and return
TQPoint ptTopLeft = mdiParent() ->mapToParent( posInFrame.topLeft() );
TQSize sz = size();
@@ -375,7 +375,7 @@ void KMdiChildView::setCaption( const TQString& szCaption )
m_szCaption = szCaption;
if ( mdiParent() )
mdiParent() ->setCaption( m_szCaption );
- else //have to call the tqparent one
+ else //have to call the parent one
TQWidget::setCaption( m_szCaption );
emit windowCaptionChanged( m_szCaption );
@@ -115,7 +115,7 @@ TQRect KMdiChildView::internalGeometry() const
// get the client area coordinates inside the MDI child frame
TQRect posInFrame = tqgeometry();
- // map these values to the tqparent of the MDI child frame
+ // map these values to the parent of the MDI child frame
// (this usually is the MDI child area) and return
TQPoint ptTopLeft = mdiParent() ->mapToParent( posInFrame.topLeft() );